###############
Code of Conduct
###############

Participation in the django CMS project is governed by a code of conduct.

The django CMS community is a pleasant one to be involved in for everyone, and
we wish to keep it that way. Participants are expected to behave and
communicate with others courteously and respectfully, whether online or in
person, and to be welcoming, friendly and polite.

We will not tolerate abusive behaviour or language or any form of harassment.

Individuals whose behaviour is a cause for concern will be give a warning, and
if necessary will be excluded from participation in official django CMS
channels (Slack group, Discourse forum, email lists, IRC channels, etc) and
events. The `Django Software Foundation
<http://djangoproject.com/foundation/>`_ will also be informed of the issue.

*****************
Raising a concern
*****************

If you have a concern about the behaviour of any member of the django CMS
community, please contact one of the members of the :ref:`core development team
<core_developers>`.

Your concerns will be taken seriously, treated as confidential and
investigated. You will be informed, in writing and as promptly as possible, of
the outcome.
